@@ -55,7 +55,7 @@
 #'   acq_function = acqf("ei")
 #'
 #'   acq_optimizer = acqo(
-#'     optimizer = opt("random_search"),
+#'     optimizer = opt("random_search", batch_size = 100),
 #'     terminator = trm("evals", n_evals = 100))
 #'
 #'   optimizer = opt("mbo",
@@ -320,3 +320,5 @@ OptimizerMbo = R6Class("OptimizerMbo",
   )
 )
 
+#' @include aaa.R
+optimizers[["mbo"]] = OptimizerMbo
