@@ -1,3 +1,4 @@
+#' @include aaa.R
 #' @importFrom R6 R6Class
 #' @import checkmate
 #' @import data.table
@@ -11,17 +12,23 @@
 #' @useDynLib mlr3mbo c_sms_indicator c_eps_indicator
 "_PACKAGE"
 
+register_bbotk = function() {
+  # nocov start
+  x = utils::getFromNamespace("mlr_optimizers", ns = "bbotk")
+  iwalk(optimizers, function(obj, nm) x$add(nm, obj))
+} # nocov end
+
+register_mlr3tuning = function() {
+  # nocov start
+  x = utils::getFromNamespace("mlr_tuners", ns = "mlr3tuning")
+  iwalk(tuners, function(obj, nm) x$add(nm, obj))
+} # nocov end
+
 .onLoad = function(libname, pkgname) { # nolint
   # nocov start
-  # add mbo to tuner dictionary
-  x = utils::getFromNamespace("mlr_tuners", ns = "mlr3tuning")
-  x$add("mbo", TunerMbo)
+  register_namespace_callback(pkgname, "bbotk", register_bbotk)
+  register_namespace_callback(pkgname, "mlr3tuning", register_mlr3tuning)
 
-  # add mbo to optimizer dictionary
-  x = utils::getFromNamespace("mlr_optimizers", ns = "bbotk")
-  x$add("mbo", OptimizerMbo)
-
-  # setup logger
   assign("lg", lgr::get_logger("bbotk"), envir = parent.env(environment()))
 
   if (Sys.getenv("IN_PKGDOWN") == "true") {
@@ -29,6 +36,12 @@
   }
 } # nocov end
 
+.onUnload = function(libpaths) { # nolint
+  # nocov start
+  walk(names(optimizers), function(id) bbotk::mlr_optimizers$remove(id))
+  walk(names(tuners), function(id) mlr3tuning::mlr_tuners$remove(id))
+} # nocov end
+
 # static code checks should not complain about commonly used data.table columns
 utils::globalVariables("y_scal")
 
